@@ -44,7 +44,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--enable-bundled-libyaml' '--disable-install-doc' '--disable-install-rdoc' '--prefix=/opt/puppetlabs/puppet' '--with-opt-dir=/opt/puppetlabs/puppet' '--enable-dtrace'"
+  CONFIG["configure_args"] = " '--enable-shared' '--enable-bundled-libyaml' '--disable-install-doc' '--disable-install-rdoc' '--prefix=/opt/puppetlabs/puppet' '--with-opt-dir=/opt/puppetlabs/puppet' 'CFLAGS=-fstack-protector-strong -fno-plt -O2' 'LDFLAGS=-L/opt/puppetlabs/puppet/lib -Wl,-rpath=/opt/puppetlabs/puppet/lib,-z,relro,-z,now' 'CPPFLAGS=-I/opt/puppetlabs/puppet/include -D_FORTIFY_SOURCE=2' '--enable-dtrace'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -132,7 +132,7 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = "-fPIC"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = ""
-  CONFIG["DLDFLAGS"] = "-Wl,--compress-debug-sections=zlib -L/opt/puppetlabs/puppet/lib  -Wl,-rpath,/opt/puppetlabs/puppet/lib"
+  CONFIG["DLDFLAGS"] = "-L/opt/puppetlabs/puppet/lib -Wl,-rpath=/opt/puppetlabs/puppet/lib,-z,relro,-z,now -Wl,--compress-debug-sections=zlib -L/opt/puppetlabs/puppet/lib  -Wl,-rpath,/opt/puppetlabs/puppet/lib"
   CONFIG["ALLOCA"] = ""
   CONFIG["MATHN"] = "yes"
   CONFIG["dsymutil"] = ""
@@ -166,7 +166,7 @@ module RbConfig
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (Ubuntu 9.4.0-1ubuntu1~20.04.2) 9.4.0\nCopyright (C) 2019 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc (Ubuntu 11.4.0-1ubuntu1~22.04) 11.4.0\nCopyright (C) 2021 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "/usr/bin/gcc"
   CONFIG["CSRCFLAG"] = ""
@@ -182,9 +182,9 @@ module RbConfig
   CONFIG["CXX"] = "g++"
   CONFIG["CPP"] = "$(CC) -E"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = " -I/opt/puppetlabs/puppet/include $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -fstack-protector-strong -rdynamic -Wl,-export-dynamic -L/opt/puppetlabs/puppet/lib  -Wl,-rpath,/opt/puppetlabs/puppet/lib"
-  CONFIG["CFLAGS"] = "-g -O2 -fPIC"
+  CONFIG["CPPFLAGS"] = "-I/opt/puppetlabs/puppet/include -D_FORTIFY_SOURCE=2 -I/opt/puppetlabs/puppet/include $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L. -L/opt/puppetlabs/puppet/lib -Wl,-rpath=/opt/puppetlabs/puppet/lib,-z,relro,-z,now -fstack-protector-strong -rdynamic -Wl,-export-dynamic -L/opt/puppetlabs/puppet/lib  -Wl,-rpath,/opt/puppetlabs/puppet/lib"
+  CONFIG["CFLAGS"] = "-fstack-protector-strong -fno-plt -O2 -fPIC"
   CONFIG["CC"] = "gcc"
   CONFIG["target_os"] = "linux"
   CONFIG["target_vendor"] = "pc"
